@@ -1,19 +1,17 @@
-from __future__ import absolute_import, division, with_statement
-
 import shutil
 import sys  # noqa
 import tempfile
 
 import pytest
-from six.moves import range, zip
 
+from pytools.tag import Tag, tag_dataclass
 from pytools.persistent_dict import (CollisionWarning, NoSuchEntryError,
         PersistentDict, ReadOnlyEntryError, WriteOncePersistentDict)
 
 
 # {{{ type for testing
 
-class PDictTestingKeyOrValue(object):
+class PDictTestingKeyOrValue:
 
     def __init__(self, val, hash_key=None):
         self.val = val
@@ -34,14 +32,19 @@ class PDictTestingKeyOrValue(object):
         key_builder.rec(key_hash, self.hash_key)
 
     def __repr__(self):
-        return "PDictTestingKeyOrValue(val=%r,hash_key=%r)" % (
-                (self.val, self.hash_key))
+        return "PDictTestingKeyOrValue(val={!r},hash_key={!r})".format(
+                self.val, self.hash_key)
 
     __str__ = __repr__
 
 # }}}
 
 
+@tag_dataclass
+class SomeTag(Tag):
+    value: str
+
+
 def test_persistent_dict_storage_and_lookup():
     try:
         tmpdir = tempfile.mkdtemp()
@@ -54,7 +57,10 @@ def test_persistent_dict_storage_and_lookup():
                     chr(65+randrange(26))
                     for i in range(n))
 
-        keys = [(randrange(2000), rand_str(), None) for i in range(20)]
+        keys = [
+                (randrange(2000)-1000, rand_str(), None, SomeTag(rand_str()),
+                    frozenset({"abc", 123}))
+                for i in range(20)]
         values = [randrange(2000) for i in range(20)]
 
         d = dict(list(zip(keys, values)))
